package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallSchoolPosition;
import com.ruoyi.mall.domain.Vo.SchoolPositionVO;

/**
 * 学校定位Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-28
 */
public interface MallSchoolPositionMapper
{
    /**
     * 查询学校定位
     *
     * @param positionId 学校定位主键
     * @return 学校定位
     */
    public MallSchoolPosition selectMallSchoolPositionByPositionId(Long positionId);

    /**
     * 查询学校定位列表
     *
     * @param mallSchoolPosition 学校定位
     * @return 学校定位集合
     */
    public List<MallSchoolPosition> selectMallSchoolPositionList(MallSchoolPosition mallSchoolPosition);

    /**
     * 新增学校定位
     *
     * @param mallSchoolPosition 学校定位
     * @return 结果
     */
    public int insertMallSchoolPosition(MallSchoolPosition mallSchoolPosition);

    /**
     * 修改学校定位
     *
     * @param mallSchoolPosition 学校定位
     * @return 结果
     */
    public int updateMallSchoolPosition(MallSchoolPosition mallSchoolPosition);

    /**
     * 删除学校定位
     *
     * @param positionId 学校定位主键
     * @return 结果
     */
    public int deleteMallSchoolPositionByPositionId(Long positionId);

    /**
     * 批量删除学校定位
     *
     * @param positionIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallSchoolPositionByPositionIds(Long[] positionIds);

    /**
     * 学校定位列表
     * @return  结果
     */
    public List<SchoolPositionVO> selectPositionList();
}
